@@ -99,6 +99,8 @@ static void frontend_qnx_get_env_settings(int *argc, char *argv[],
          "info", sizeof(g_defaults.dirs[DEFAULT_DIR_CORE_INFO]));
    fill_pathname_join(g_defaults.dirs[DEFAULT_DIR_OVERLAY], data_path,
          "overlays", sizeof(g_defaults.dirs[DEFAULT_DIR_OVERLAY]));
+   fill_pathname_join(g_defaults.dirs[DEFAULT_DIR_OSK_OVERLAY], data_path,
+         "overlays/keyboards", sizeof(g_defaults.dirs[DEFAULT_DIR_OSK_OVERLAY]));
    /* user data */
    fill_pathname_join(g_defaults.dirs[DEFAULT_DIR_CHEATS], user_path,
          "cheats", sizeof(g_defaults.dirs[DEFAULT_DIR_CHEATS]));
@@ -150,9 +152,9 @@ static void frontend_qnx_get_env_settings(int *argc, char *argv[],
             "cp -r %s/. %s", assets_path, data_path);
 
       if (system(copy_command) == -1)
-         RARCH_ERR("Asset copy failed: Shell could not be run.\n" );
+         RARCH_ERR("Asset copy failed: Shell could not be run.\n");
       else
-         RARCH_LOG( "Asset copy successful.\n");
+         RARCH_LOG("Asset copy successful.\n");
    }
 
    /* set GLUI as default menu */
