@@ -20,12 +20,10 @@
 #include <algorithm>
 #include <stdio.h>
 #include <compat/strl.h>
+#include <retro_miscellaneous.h>
 #include "glslang_util.h"
 #include "../../verbosity.h"
 
-using namespace std;
-using namespace spirv_cross;
-
 static const char *texture_semantic_names[] = {
    "Original",
    "Source",
@@ -52,6 +50,13 @@ static const char *semantic_uniform_names[] = {
    "FinalViewportSize",
    "FrameCount",
    "FrameDirection",
+   "FrameTimeDelta",
+   "OriginalFPS",
+   "Rotation",
+   "OriginalAspect",
+   "OriginalAspectRotated",
+   "TotalSubFrames",
+   "CurrentSubFrame",
 };
 
 static slang_texture_semantic slang_name_to_texture_semantic(
@@ -131,7 +136,7 @@ static bool set_ubo_texture_offset(
    {
       if (active_offset != offset)
       {
-         RARCH_ERR("[slang]: Vertex and fragment have"
+         RARCH_ERR("[Slang] Vertex and fragment have"
                " different offsets for same semantic %s #%u (%u vs. %u).\n",
                texture_semantic_uniform_names[semantic],
                index,
@@ -161,7 +166,7 @@ static bool set_ubo_float_parameter_offset(
    {
       if (active_offset != offset)
       {
-         RARCH_ERR("[slang]: Vertex and fragment have different"
+         RARCH_ERR("[Slang] Vertex and fragment have different"
                " offsets for same parameter #%u (%u vs. %u).\n",
                index,
                unsigned(active_offset),
@@ -170,10 +175,10 @@ static bool set_ubo_float_parameter_offset(
       }
    }
 
-   if (  (sem.num_components != num_components) && 
+   if (  (sem.num_components != num_components) &&
          (sem.uniform || sem.push_constant))
    {
-      RARCH_ERR("[slang]: Vertex and fragment have different "
+      RARCH_ERR("[Slang] Vertex and fragment have different "
             "components for same parameter #%u (%u vs. %u).\n",
             index,
             unsigned(sem.num_components),
@@ -200,7 +205,7 @@ static bool set_ubo_offset(
    {
       if (active_offset != offset)
       {
-         RARCH_ERR("[slang]: Vertex and fragment have "
+         RARCH_ERR("[Slang] Vertex and fragment have "
                "different offsets for same semantic %s (%u vs. %u).\n",
                semantic_uniform_names[semantic],
                unsigned(active_offset),
@@ -210,10 +215,10 @@ static bool set_ubo_offset(
 
    }
 
-   if (  (sem.num_components != num_components) && 
+   if (  (sem.num_components != num_components) &&
          (sem.uniform || sem.push_constant))
    {
-      RARCH_ERR("[slang]: Vertex and fragment have different"
+      RARCH_ERR("[Slang] Vertex and fragment have different"
             " components for same semantic %s (%u vs. %u).\n",
             semantic_uniform_names[semantic],
             unsigned(sem.num_components),
@@ -227,45 +232,91 @@ static bool set_ubo_offset(
    return true;
 }
 
-static bool validate_type_for_semantic(const SPIRType &type, slang_semantic sem)
+static bool validate_type_for_semantic(const spirv_cross::SPIRType &type, slang_semantic sem)
 {
    if (!type.array.empty())
       return false;
-   if (type.basetype != SPIRType::Float && type.basetype != SPIRType::Int && type.basetype != SPIRType::UInt)
+   if (     type.basetype != spirv_cross::SPIRType::Float
+         && type.basetype != spirv_cross::SPIRType::Int
+         && type.basetype != spirv_cross::SPIRType::UInt)
       return false;
 
    switch (sem)
    {
          /* mat4 */
       case SLANG_SEMANTIC_MVP:
-         return type.basetype == SPIRType::Float && type.vecsize == 4 && type.columns == 4;
+         return
+               type.basetype == spirv_cross::SPIRType::Float
+            && type.vecsize  == 4
+            && type.columns  == 4;
          /* uint */
       case SLANG_SEMANTIC_FRAME_COUNT:
-         return type.basetype == SPIRType::UInt  && type.vecsize == 1 && type.columns == 1;
+         return type.basetype == spirv_cross::SPIRType::UInt
+            &&  type.vecsize  == 1
+            &&  type.columns  == 1;
+         /* int */
+      case SLANG_SEMANTIC_TOTAL_SUBFRAMES:
+         return type.basetype == spirv_cross::SPIRType::UInt
+            &&  type.vecsize  == 1
+            &&  type.columns  == 1;
+         /* int */
+      case SLANG_SEMANTIC_CURRENT_SUBFRAME:
+         return type.basetype == spirv_cross::SPIRType::UInt
+            &&  type.vecsize  == 1
+            &&  type.columns  == 1;
          /* int */
       case SLANG_SEMANTIC_FRAME_DIRECTION:
-         return type.basetype == SPIRType::Int   && type.vecsize == 1 && type.columns == 1;
+         return type.basetype == spirv_cross::SPIRType::Int
+            &&  type.vecsize  == 1
+            &&  type.columns  == 1;
+         /* uint */
+      case SLANG_SEMANTIC_FRAME_TIME_DELTA:
+         return type.basetype == spirv_cross::SPIRType::UInt
+            &&  type.vecsize  == 1
+            &&  type.columns  == 1;
+         /* uint */
+      case SLANG_SEMANTIC_ORIGINAL_FPS:
+         return type.basetype == spirv_cross::SPIRType::Float
+            &&  type.vecsize  == 1
+            &&  type.columns  == 1;
+         /* uint */
+      case SLANG_SEMANTIC_ROTATION:
+         return type.basetype == spirv_cross::SPIRType::UInt
+            &&  type.vecsize  == 1
+            &&  type.columns  == 1;
+      case SLANG_SEMANTIC_CORE_ASPECT:
+         return type.basetype == spirv_cross::SPIRType::Float
+            &&  type.vecsize  == 1
+            &&  type.columns  == 1;
+      case SLANG_SEMANTIC_CORE_ASPECT_ROT:
+         return type.basetype == spirv_cross::SPIRType::Float
+            &&  type.vecsize  == 1
+            &&  type.columns  == 1;
          /* float */
       case SLANG_SEMANTIC_FLOAT_PARAMETER:
-         return type.basetype == SPIRType::Float && type.vecsize == 1 && type.columns == 1;
+         return type.basetype == spirv_cross::SPIRType::Float
+            &&  type.vecsize  == 1
+            &&  type.columns  == 1;
          /* vec4 */
       default:
-         return type.basetype == SPIRType::Float && type.vecsize == 4 && type.columns == 1;
+         break;
    }
+   return type.basetype == spirv_cross::SPIRType::Float
+      &&  type.vecsize  == 4
+      &&  type.columns  == 1;
 }
 
-static bool validate_type_for_texture_semantic(const SPIRType &type)
+static bool validate_type_for_texture_semantic(const spirv_cross::SPIRType &type)
 {
-   if (!type.array.empty())
-      return false;
-   return (type.basetype == SPIRType::Float) && 
-          (type.vecsize  == 4)               && 
-          (type.columns  == 1);
+   return    (type.array.empty())
+          && (type.basetype == spirv_cross::SPIRType::Float)
+          && (type.vecsize  == 4)
+          && (type.columns  == 1);
 }
 
 static bool add_active_buffer_ranges(
-      const Compiler &compiler,
-      const Resource &resource,
+      const spirv_cross::Compiler &compiler,
+      const spirv_cross::Resource &resource,
       slang_reflection *reflection,
       bool push_constant)
 {
@@ -279,7 +330,7 @@ static bool add_active_buffer_ranges(
       unsigned tex_sem_index         = 0;
       const std::string &name        = compiler.get_member_name(
             resource.base_type_id, ranges[i].index);
-      const SPIRType &type           = compiler.get_type(
+      const spirv_cross::SPIRType &type = compiler.get_type(
             compiler.get_type(resource.base_type_id).member_types[
             ranges[i].index]);
       slang_semantic sem             = slang_uniform_name_to_semantic(
@@ -290,7 +341,7 @@ static bool add_active_buffer_ranges(
 
       if (tex_sem == SLANG_TEXTURE_SEMANTIC_PASS_OUTPUT && tex_sem_index >= reflection->pass_number)
       {
-         RARCH_ERR("[slang]: Non causal filter chain detected. "
+         RARCH_ERR("[Slang] Non causal filter chain detected. "
                "Shader is trying to use output from pass #%u,"
                " but this shader is pass #%u.\n",
                tex_sem_index, reflection->pass_number);
@@ -301,7 +352,7 @@ static bool add_active_buffer_ranges(
       {
          if (!validate_type_for_semantic(type, sem))
          {
-            RARCH_ERR("[slang]: Underlying type of semantic is invalid.\n");
+            RARCH_ERR("[Slang] Underlying type of semantic is invalid.\n");
             return false;
          }
 
@@ -325,7 +376,7 @@ static bool add_active_buffer_ranges(
       {
          if (!validate_type_for_texture_semantic(type))
          {
-            RARCH_ERR("[slang]: Underlying type of texture"
+            RARCH_ERR("[Slang] Underlying type of texture"
                   " semantic is invalid.\n");
             return false;
          }
@@ -337,7 +388,7 @@ static bool add_active_buffer_ranges(
       else
       {
          /* TODO - Try to print name */
-         RARCH_ERR("[slang]: Unknown semantic found.\n");
+         RARCH_ERR("[Slang] Unknown semantic found.\n");
          return false;
       }
    }
@@ -357,10 +408,10 @@ slang_reflection::slang_reflection()
 }
 
 bool slang_reflect(
-      const Compiler &vertex_compiler,
-      const Compiler &fragment_compiler,
-      const ShaderResources &vertex,
-      const ShaderResources &fragment,
+      const spirv_cross::Compiler &vertex_compiler,
+      const spirv_cross::Compiler &fragment_compiler,
+      const spirv_cross::ShaderResources &vertex,
+      const spirv_cross::ShaderResources &fragment,
       slang_reflection *reflection)
 {
    uint32_t location_mask = 0;
@@ -369,37 +420,37 @@ bool slang_reflect(
 
    /* Validate use of unexpected types. */
    if (
-         !vertex.sampled_images.empty()    ||
-         !vertex.storage_buffers.empty()   ||
-         !vertex.subpass_inputs.empty()    ||
-         !vertex.storage_images.empty()    ||
-         !vertex.atomic_counters.empty()   ||
-         !fragment.storage_buffers.empty() ||
-         !fragment.subpass_inputs.empty()  ||
-         !fragment.storage_images.empty()  ||
-         !fragment.atomic_counters.empty())
+            !vertex.sampled_images.empty()
+         || !vertex.storage_buffers.empty()
+         || !vertex.subpass_inputs.empty()
+         || !vertex.storage_images.empty()
+         || !vertex.atomic_counters.empty()
+         || !fragment.storage_buffers.empty()
+         || !fragment.subpass_inputs.empty()
+         || !fragment.storage_images.empty()
+         || !fragment.atomic_counters.empty())
    {
-      RARCH_ERR("[slang]: Invalid resource type detected.\n");
+      RARCH_ERR("[Slang] Invalid resource type detected.\n");
       return false;
    }
 
    /* Validate vertex input. */
    if (vertex.stage_inputs.size() != 2)
    {
-      RARCH_ERR("[slang]: Vertex must have two attributes.\n");
+      RARCH_ERR("[Slang] Vertex must have two attributes.\n");
       return false;
    }
 
    if (fragment.stage_outputs.size() != 1)
    {
-      RARCH_ERR("[slang]: Multiple render targets not supported.\n");
+      RARCH_ERR("[Slang] Multiple render targets not supported.\n");
       return false;
    }
 
    if (fragment_compiler.get_decoration(
             fragment.stage_outputs[0].id, spv::DecorationLocation) != 0)
    {
-      RARCH_ERR("[slang]: Render target must use location = 0.\n");
+      RARCH_ERR("[Slang] Render target must use location = 0.\n");
       return false;
    }
 
@@ -409,7 +460,7 @@ bool slang_reflect(
 
    if (location_mask != 0x3)
    {
-      RARCH_ERR("[slang]: The two vertex attributes do not"
+      RARCH_ERR("[Slang] The two vertex attributes do not"
             " use location = 0 and location = 1.\n");
       return false;
    }
@@ -417,26 +468,26 @@ bool slang_reflect(
    /* Validate the single uniform buffer. */
    if (vertex.uniform_buffers.size() > 1)
    {
-      RARCH_ERR("[slang]: Vertex must use zero or one uniform buffer.\n");
+      RARCH_ERR("[Slang] Vertex must use zero or one uniform buffer.\n");
       return false;
    }
 
    if (fragment.uniform_buffers.size() > 1)
    {
-      RARCH_ERR("[slang]: Fragment must use zero or one uniform buffer.\n");
+      RARCH_ERR("[Slang] Fragment must use zero or one uniform buffer.\n");
       return false;
    }
 
    /* Validate the single push constant buffer. */
    if (vertex.push_constant_buffers.size() > 1)
    {
-      RARCH_ERR("[slang]: Vertex must use zero or one push constant buffers.\n");
+      RARCH_ERR("[Slang] Vertex must use zero or one push constant buffers.\n");
       return false;
    }
 
    if (fragment.push_constant_buffers.size() > 1)
    {
-      RARCH_ERR("[slang]: Fragment must use zero or one push cosntant buffer.\n");
+      RARCH_ERR("[Slang] Fragment must use zero or one push cosntant buffer.\n");
       return false;
    }
 
@@ -449,7 +500,7 @@ bool slang_reflect(
          vertex_compiler.get_decoration(
             vertex_ubo, spv::DecorationDescriptorSet) != 0)
    {
-      RARCH_ERR("[slang]: Resources must use descriptor set #0.\n");
+      RARCH_ERR("[Slang] Resources must use descriptor set #0.\n");
       return false;
    }
 
@@ -457,15 +508,15 @@ bool slang_reflect(
          fragment_compiler.get_decoration(
             fragment_ubo, spv::DecorationDescriptorSet) != 0)
    {
-      RARCH_ERR("[slang]: Resources must use descriptor set #0.\n");
+      RARCH_ERR("[Slang] Resources must use descriptor set #0.\n");
       return false;
    }
 
-   unsigned vertex_ubo_binding   = vertex_ubo 
-      ? vertex_compiler.get_decoration(vertex_ubo, spv::DecorationBinding) 
+   unsigned vertex_ubo_binding   = vertex_ubo
+      ? vertex_compiler.get_decoration(vertex_ubo, spv::DecorationBinding)
       : -1u;
-   unsigned fragment_ubo_binding = fragment_ubo 
-      ? fragment_compiler.get_decoration(fragment_ubo, spv::DecorationBinding) 
+   unsigned fragment_ubo_binding = fragment_ubo
+      ? fragment_compiler.get_decoration(fragment_ubo, spv::DecorationBinding)
       : -1u;
    bool has_ubo                  = vertex_ubo || fragment_ubo;
 
@@ -473,17 +524,17 @@ bool slang_reflect(
          (fragment_ubo_binding != -1u) &&
          (vertex_ubo_binding   != fragment_ubo_binding))
    {
-      RARCH_ERR("[slang]: Vertex and fragment uniform buffer must have same binding.\n");
+      RARCH_ERR("[Slang] Vertex and fragment uniform buffer must have same binding.\n");
       return false;
    }
 
    unsigned ubo_binding = (vertex_ubo_binding != -1u)
-      ? vertex_ubo_binding 
+      ? vertex_ubo_binding
       : fragment_ubo_binding;
 
    if (has_ubo && ubo_binding >= SLANG_NUM_BINDINGS)
    {
-      RARCH_ERR("[slang]: Binding %u is out of range.\n", ubo_binding);
+      RARCH_ERR("[Slang] Binding %u is out of range.\n", ubo_binding);
       return false;
    }
 
@@ -495,47 +546,51 @@ bool slang_reflect(
 
    if (vertex_ubo)
    {
+      size_t _y;
       reflection->ubo_stage_mask |= SLANG_STAGE_VERTEX_MASK;
-      reflection->ubo_size        = max(reflection->ubo_size,
-            vertex_compiler.get_declared_struct_size(
+      _y = vertex_compiler.get_declared_struct_size(
                vertex_compiler.get_type(
-                  vertex.uniform_buffers[0].base_type_id)));
+                  vertex.uniform_buffers[0].base_type_id));
+      reflection->ubo_size        = MAX(reflection->ubo_size, _y);
    }
 
    if (fragment_ubo)
    {
+      size_t _y;
       reflection->ubo_stage_mask |= SLANG_STAGE_FRAGMENT_MASK;
-      reflection->ubo_size        = max(reflection->ubo_size,
-            fragment_compiler.get_declared_struct_size(
+      _y = fragment_compiler.get_declared_struct_size(
                fragment_compiler.get_type(
-                  fragment.uniform_buffers[0].base_type_id)));
+                  fragment.uniform_buffers[0].base_type_id));
+      reflection->ubo_size        = MAX(reflection->ubo_size, _y);
    }
 
    if (vertex_push)
    {
+      size_t _y;
       reflection->push_constant_stage_mask |= SLANG_STAGE_VERTEX_MASK;
-      reflection->push_constant_size        = max(
-            reflection->push_constant_size,
-            vertex_compiler.get_declared_struct_size(
+      _y = vertex_compiler.get_declared_struct_size(
                vertex_compiler.get_type(
-                  vertex.push_constant_buffers[0].base_type_id)));
+                  vertex.push_constant_buffers[0].base_type_id));
+      reflection->push_constant_size        = MAX(
+            reflection->push_constant_size, _y);
    }
 
    if (fragment_push)
    {
+      size_t _y;
       reflection->push_constant_stage_mask |= SLANG_STAGE_FRAGMENT_MASK;
-      reflection->push_constant_size        = max(
-            reflection->push_constant_size,
-            fragment_compiler.get_declared_struct_size(
+      _y = fragment_compiler.get_declared_struct_size(
                fragment_compiler.get_type(
-                  fragment.push_constant_buffers[0].base_type_id)));
+                  fragment.push_constant_buffers[0].base_type_id));
+      reflection->push_constant_size        = MAX(
+            reflection->push_constant_size, _y);
    }
 
-   /* Validate push constant size against Vulkan's 
+   /* Validate push constant size against Vulkan's
     * minimum spec to avoid cross-vendor issues. */
    if (reflection->push_constant_size > 128)
    {
-      RARCH_ERR("[slang]: Exceeded maximum size of 128 bytes"
+      RARCH_ERR("[Slang] Exceeded maximum size of 128 bytes"
             " for push constant buffer.\n");
       return false;
    }
@@ -570,19 +625,19 @@ bool slang_reflect(
 
       if (set != 0)
       {
-         RARCH_ERR("[slang]: Resources must use descriptor set #0.\n");
+         RARCH_ERR("[Slang] Resources must use descriptor set #0.\n");
          return false;
       }
 
       if (binding >= SLANG_NUM_BINDINGS)
       {
-         RARCH_ERR("[slang]: Binding %u is out of range.\n", ubo_binding);
+         RARCH_ERR("[Slang] Binding %u is out of range.\n", ubo_binding);
          return false;
       }
 
       if (binding_mask & (1 << binding))
       {
-         RARCH_ERR("[slang]: Binding %u is already in use.\n", binding);
+         RARCH_ERR("[Slang] Binding %u is already in use.\n", binding);
          return false;
       }
       binding_mask |= 1 << binding;
@@ -593,7 +648,7 @@ bool slang_reflect(
 
       if (index == SLANG_TEXTURE_SEMANTIC_PASS_OUTPUT && array_index >= reflection->pass_number)
       {
-         RARCH_ERR("[slang]: Non causal filter chain detected. "
+         RARCH_ERR("[Slang] Non causal filter chain detected. "
                "Shader is trying to use output from pass #%u,"
                " but this shader is pass #%u.\n",
                array_index, reflection->pass_number);
@@ -601,15 +656,15 @@ bool slang_reflect(
       }
       else if (index == SLANG_INVALID_TEXTURE_SEMANTIC)
       {
-         RARCH_ERR("[slang]: Texture name '%s' not found in semantic map, "
+         RARCH_ERR("[Slang] Texture name '%s' not found in semantic map, "
                    "Probably the texture name or pass alias is not defined "
-                   "in the preset (Non-semantic textures not supported yet)\n", 
+                   "in the preset (Non-semantic textures not supported yet)\n",
                    fragment.sampled_images[i].name.c_str());
          return false;
       }
 
       resize_minimum(reflection->semantic_textures[index], array_index + 1);
-      slang_texture_semantic_meta &semantic = 
+      slang_texture_semantic_meta &semantic =
          reflection->semantic_textures[index][array_index];
       semantic.binding                      = binding;
       semantic.stage_mask                   = SLANG_STAGE_FRAGMENT_MASK;
@@ -617,8 +672,8 @@ bool slang_reflect(
    }
 
 #ifdef DEBUG
-   RARCH_LOG("[slang]: Reflection\n");
-   RARCH_LOG("[slang]:   Textures:\n");
+   RARCH_LOG("[Slang] Reflection\n");
+   RARCH_LOG("[Slang]   Textures:\n");
 
    for (i = 0; i < SLANG_NUM_TEXTURE_SEMANTICS; i++)
    {
@@ -626,17 +681,17 @@ bool slang_reflect(
       for (auto &sem : reflection->semantic_textures[i])
       {
          if (sem.texture)
-            RARCH_LOG("[slang]:      %s (#%u)\n",
+            RARCH_LOG("[Slang]      %s (#%u)\n",
                   texture_semantic_names[i], index);
          index++;
       }
    }
 
-   RARCH_LOG("[slang]:\n");
-   RARCH_LOG("[slang]:   Uniforms (Vertex: %s, Fragment: %s):\n",
+   RARCH_LOG("[Slang]\n");
+   RARCH_LOG("[Slang]   Uniforms (Vertex: %s, Fragment: %s):\n",
          reflection->ubo_stage_mask & SLANG_STAGE_VERTEX_MASK ? "yes": "no",
          reflection->ubo_stage_mask & SLANG_STAGE_FRAGMENT_MASK ? "yes": "no");
-   RARCH_LOG("[slang]:   Push Constants (Vertex: %s, Fragment: %s):\n",
+   RARCH_LOG("[Slang]   Push Constants (Vertex: %s, Fragment: %s):\n",
          reflection->push_constant_stage_mask & SLANG_STAGE_VERTEX_MASK ? "yes": "no",
          reflection->push_constant_stage_mask & SLANG_STAGE_FRAGMENT_MASK ? "yes": "no");
 
@@ -644,14 +699,14 @@ bool slang_reflect(
    {
       if (reflection->semantics[i].uniform)
       {
-         RARCH_LOG("[slang]:      %s (Offset: %u)\n",
+         RARCH_LOG("[Slang]      %s (Offset: %u)\n",
                semantic_uniform_names[i],
                unsigned(reflection->semantics[i].ubo_offset));
       }
 
       if (reflection->semantics[i].push_constant)
       {
-         RARCH_LOG("[slang]:      %s (PushOffset: %u)\n",
+         RARCH_LOG("[Slang]      %s (PushOffset: %u)\n",
                semantic_uniform_names[i],
                unsigned(reflection->semantics[i].push_constant_offset));
       }
@@ -664,7 +719,7 @@ bool slang_reflect(
       {
          if (sem.uniform)
          {
-            RARCH_LOG("[slang]:      %s (#%u) (Offset: %u)\n",
+            RARCH_LOG("[Slang]      %s (#%u) (Offset: %u)\n",
                   texture_semantic_uniform_names[i],
                   index,
                   unsigned(sem.ubo_offset));
@@ -672,7 +727,7 @@ bool slang_reflect(
 
          if (sem.push_constant)
          {
-            RARCH_LOG("[slang]:      %s (#%u) (PushOffset: %u)\n",
+            RARCH_LOG("[Slang]      %s (#%u) (PushOffset: %u)\n",
                   texture_semantic_uniform_names[i],
                   index,
                   unsigned(sem.push_constant_offset));
@@ -683,9 +738,9 @@ bool slang_reflect(
 
    {
       char buf[64];
-      strlcpy(buf, "[slang]:\n", sizeof(buf));
-      strlcat(buf, FILE_PATH_LOG_INFO, sizeof(buf));
-      strlcat(buf, " [slang]:   Parameters:\n", sizeof(buf));
+      size_t _len = strlcpy(buf, "[Slang]\n", sizeof(buf));
+      _len       += strlcpy(buf + _len, FILE_PATH_LOG_INFO, sizeof(buf) - _len);
+      strlcpy(buf + _len, "\n[Slang]   Parameters:\n", sizeof(buf) - _len);
       RARCH_LOG(buf);
    }
 
@@ -698,10 +753,10 @@ bool slang_reflect(
          continue;
 
       if (param->uniform)
-         RARCH_LOG("[slang]:     #%u (Offset: %u)\n", i,
+         RARCH_LOG("[Slang]     #%u (Offset: %u)\n", i,
                (unsigned int)param->ubo_offset);
       if (param->push_constant)
-         RARCH_LOG("[slang]:     #%u (PushOffset: %u)\n", i,
+         RARCH_LOG("[Slang]     #%u (PushOffset: %u)\n", i,
                (unsigned int)param->push_constant_offset);
    }
 #endif
@@ -715,18 +770,18 @@ bool slang_reflect_spirv(const std::vector<uint32_t> &vertex,
 {
    try
    {
-      Compiler vertex_compiler(vertex);
-      Compiler fragment_compiler(fragment);
+      spirv_cross::Compiler vertex_compiler(vertex);
+      spirv_cross::Compiler fragment_compiler(fragment);
       spirv_cross::ShaderResources
          vertex_resources     = vertex_compiler.get_shader_resources();
-      spirv_cross::ShaderResources 
+      spirv_cross::ShaderResources
          fragment_resources   = fragment_compiler.get_shader_resources();
 
       if (!slang_reflect(vertex_compiler, fragment_compiler,
                vertex_resources, fragment_resources,
                reflection))
       {
-         RARCH_ERR("[slang]: Failed to reflect SPIR-V."
+         RARCH_ERR("[Slang] Failed to reflect SPIR-V."
                " Resource usage is inconsistent with expectations.\n");
          return false;
       }
@@ -735,7 +790,7 @@ bool slang_reflect_spirv(const std::vector<uint32_t> &vertex,
    }
    catch (const std::exception &e)
    {
-      RARCH_ERR("[slang]: SPIRV-Cross threw exception: %s.\n", e.what());
+      RARCH_ERR("[Slang] SPIRV-Cross threw exception: %s.\n", e.what());
       return false;
    }
 }
