@@ -6,19 +6,11 @@
 #define HAVE_COCOATOUCH
 #endif
 
-#ifndef HAVE_IOS_CUSTOMKEYBOARD
-#define HAVE_IOS_CUSTOMKEYBOARD
-#endif
-
-#ifndef HAVE_IOS_SWIFT
-#define HAVE_IOS_SWIFT
-#endif
-
-#ifndef HAVE_IOS_TOUCHMOUSE
-#define HAVE_IOS_TOUCHMOUSE
-#endif
-
 #include "libretro-common/include/libretro.h"
-#import "../ui/drivers/cocoa/cocoa_common.h"
 #include "../../input/drivers_keyboard/keyboard_event_apple.h"
 #include "../../input/input_keymaps.h"
+#include "../../paths.h"
+
+#import "../ui/drivers/cocoa/cocoa_common.h"
+#import "../../ui/drivers/cocoa/RetroArchPlaylistManager.h"
+#import "../ui/drivers/cocoa/apple_platform.h"
