@@ -22,11 +22,18 @@
 #include "config.h"
 #endif
 
+#if defined(_WIN32_WINNT) && _WIN32_WINNT < 0x0500 || defined(_XBOX)
+#ifndef LEGACY_WIN32
+#define LEGACY_WIN32
+#endif
+#endif
+
 #include <encodings/utf.h>
 #include <string/stdstring.h>
 #include <streams/file_stream.h>
 #include <time/rtime.h>
 
+#include "configuration.h"
 #include "content.h"
 #include "core.h"
 #include "dynamic.h"
@@ -40,27 +47,28 @@
 static int16_t input_state_get_last(unsigned port,
       unsigned device, unsigned index, unsigned id)
 {
-   int i;
    runloop_state_t      *runloop_st = runloop_state_get_ptr();
 
-   if (!runloop_st->input_state_list)
-      return 0;
-
-   /* find list item */
-   for (i = 0; i < runloop_st->input_state_list->size; i++)
+   if (runloop_st->input_state_list)
    {
-      input_list_element *element =
-         (input_list_element*)runloop_st->input_state_list->data[i];
-
-      if (  (element->port   == port)   &&
-            (element->device == device) &&
-            (element->index  == index))
+      int i;
+      /* find list item */
+      for (i = 0; i < runloop_st->input_state_list->size; i++)
       {
-         if (id < element->state_size)
-            return element->state[id];
-         return 0;
+         input_list_element *element =
+            (input_list_element*)runloop_st->input_state_list->data[i];
+
+         if (     (element->port   == port)
+               && (element->device == device)
+               && (element->index  == index))
+         {
+            if (id < element->state_size)
+               return element->state[id];
+            break;
+         }
       }
    }
+
    return 0;
 }
 
@@ -140,40 +148,36 @@ void runahead_set_load_content_info(void *data,
 #if defined(HAVE_DYNAMIC) || defined(HAVE_DYLIB)
 static void strcat_alloc(char **dst, const char *s)
 {
-   size_t len1;
-   char *src          = *dst;
+   size_t _len;
+   char *src    = *dst;
 
    if (!src)
    {
       if (s)
       {
-         size_t   len = strlen(s);
-         if (len != 0)
-         {
-            char *_dst= (char*)malloc(len + 1);
-            strcpy_literal(_dst, s);
-            src       = _dst;
-         }
+         size_t __len = strlen(s);
+         if (__len != 0)
+            src = strldup(s, __len + 1);
          else
-            src       = NULL;
+            src = NULL;
       }
       else
-         src          = (char*)calloc(1,1);
+         src    = (char*)calloc(1,1);
 
-      *dst            = src;
+      *dst      = src;
       return;
    }
 
    if (!s)
       return;
 
-   len1               = strlen(src);
+   _len = strlen(src);
 
-   if (!(src = (char*)realloc(src, len1 + strlen(s) + 1)))
+   if (!(src = (char*)realloc(src, _len + strlen(s) + 1)))
       return;
 
-   *dst               = src;
-   strcpy_literal(src + len1, s);
+   *dst = src;
+   strcpy(src + _len, s);
 }
 
 void runahead_secondary_core_destroy(void *data)
@@ -202,7 +206,6 @@ void runahead_secondary_core_destroy(void *data)
 
 static char *get_tmpdir_alloc(const char *override_dir)
 {
-   const char *src    = NULL;
    char *path         = NULL;
 #ifdef _WIN32
 #ifdef LEGACY_WIN32
@@ -227,6 +230,7 @@ static char *get_tmpdir_alloc(const char *override_dir)
    free(wide_str);
 #endif
 #else
+   const char *src    = NULL;
 #if defined ANDROID
    src                = override_dir;
 #else
@@ -240,13 +244,9 @@ static char *get_tmpdir_alloc(const char *override_dir)
 #endif
    if (src)
    {
-      size_t   len    = strlen(src);
-      if (len != 0)
-      {
-         char *dst    = (char*)malloc(len + 1);
-         strcpy_literal(dst, src);
-         path         = dst;
-      }
+      size_t _len     = strlen(src);
+      if (_len != 0)
+         path         = strldup(src, _len + 1);
    }
    else
       path            = (char*)calloc(1,1);
@@ -258,7 +258,6 @@ static bool write_file_with_random_name(char **temp_dll_path,
       const char *tmp_path, const void* data, ssize_t dataSize)
 {
    int i;
-   size_t ext_len;
    char number_buf[32];
    bool okay                = false;
    const char *prefix       = "tmp";
@@ -269,25 +268,23 @@ static bool write_file_with_random_name(char **temp_dll_path,
 
    if (src)
    {
-      size_t   len          = strlen(src);
-      if (len != 0)
-      {
-         char *dst          = (char*)malloc(len + 1);
-         strcpy_literal(dst, src);
-         ext                = dst;
-      }
+      size_t _len           = strlen(src);
+      if (_len != 0)
+         ext                = strldup(src, _len + 1);
    }
    else
       ext                   = (char*)calloc(1,1);
 
-   ext_len                  = strlen(ext);
-
-   if (ext_len > 0)
+   if (ext)
    {
-      strcat_alloc(&ext, ".");
-      memmove(ext + 1, ext, ext_len);
-      ext[0] = '.';
-      ext_len++;
+      size_t ext_len        = strlen(ext);
+      if (ext_len > 0)
+      {
+         strcat_alloc(&ext, ".");
+         memmove(ext + 1, ext, ext_len);
+         ext[0] = '.';
+         ext_len++;
+      }
    }
 
    /* Try up to 30 'random' filenames before giving up */
@@ -334,7 +331,7 @@ static char *copy_core_to_temp_file(
    int64_t  dll_file_size      = 0;
    const char  *core_base_name = path_basename_nocompression(core_path);
 
-   if (strlen(core_base_name) == 0)
+   if (string_is_empty(core_base_name))
       return NULL;
 
    if (!(tmpdir = get_tmpdir_alloc(dir_libretro)))
@@ -391,7 +388,7 @@ end:
 static bool runloop_environment_secondary_core_hook(
       unsigned cmd, void *data)
 {
-   runloop_state_t *runloop_st    = runloop_state_get_ptr(); 
+   runloop_state_t *runloop_st    = runloop_state_get_ptr();
    bool result                    = runloop_environment_cb(cmd, data);
 
    if (runloop_st->flags & RUNLOOP_FLAG_HAS_VARIABLE_UPDATE)
@@ -411,20 +408,19 @@ static bool runloop_environment_secondary_core_hook(
 
 void runahead_clear_controller_port_map(void *data)
 {
-   int port;
+   int i;
    runloop_state_t *runloop_st = (runloop_state_t*)data;
-   for (port = 0; port < MAX_USERS; port++)
-      runloop_st->port_map[port] = -1;
+   for (i = 0; i < MAX_USERS; i++)
+      runloop_st->port_map[i] = -1;
 }
 
 static bool secondary_core_create(runloop_state_t *runloop_st,
-      settings_t *settings)
+      const char *path_directory_libretro, unsigned num_active_users)
 {
    const enum rarch_core_type
-      last_core_type           = runloop_st->last_core_type;
-   rarch_system_info_t *info   = &runloop_st->system;
-   unsigned num_active_users   = settings->uints.input_max_users;
-   uint8_t flags               = content_get_flags();
+      last_core_type             = runloop_st->last_core_type;
+   rarch_system_info_t *sys_info = &runloop_st->system;
+   uint8_t flags                 = content_get_flags();
 
    if (     (last_core_type != CORE_TYPE_PLAIN)
          || (!runloop_st->load_content_info)
@@ -435,8 +431,7 @@ static bool secondary_core_create(runloop_state_t *runloop_st,
       free(runloop_st->secondary_library_path);
    runloop_st->secondary_library_path = NULL;
    runloop_st->secondary_library_path = copy_core_to_temp_file(
-		   path_get(RARCH_PATH_CORE),
-		   settings->paths.directory_libretro);
+		   path_get(RARCH_PATH_CORE), path_directory_libretro);
 
    if (!runloop_st->secondary_library_path)
       return false;
@@ -504,18 +499,18 @@ static bool secondary_core_create(runloop_state_t *runloop_st,
    runloop_st->secondary_core.retro_set_input_poll(
          runloop_st->secondary_callbacks.poll_cb);
 
-   if (info)
+   if (sys_info)
    {
-      int port;
+      ssize_t port;
       for (port = 0; port < MAX_USERS; port++)
       {
-         if (port < (int)info->ports.size)
+         if (port < (ssize_t)sys_info->ports.size)
          {
-            unsigned device = (port < (int)num_active_users) ?
-                  runloop_st->port_map[port] : RETRO_DEVICE_NONE;
-
+            unsigned device = (port < (ssize_t)num_active_users)
+                  ? runloop_st->port_map[port]
+                  : RETRO_DEVICE_NONE;
             runloop_st->secondary_core.retro_set_controller_port_device(
-                  port, device);
+                  (unsigned)port, device);
          }
       }
    }
@@ -534,25 +529,26 @@ error:
 #if defined(HAVE_DYNAMIC) || defined(HAVE_DYLIB)
 bool secondary_core_ensure_exists(void *data, settings_t *settings)
 {
-   runloop_state_t *runloop_st   = (runloop_state_t*)data;
+   runloop_state_t *runloop_st         = (runloop_state_t*)data;
+   const char *path_directory_libretro = settings->paths.directory_libretro;
+   unsigned input_max_users            = settings->uints.input_max_users;
    if (!runloop_st->secondary_lib_handle)
-      if (!secondary_core_create(runloop_st, settings))
-         return false;
+      return secondary_core_create(runloop_st, path_directory_libretro,
+               input_max_users);
    return true;
 }
 #endif
 
 #if defined(HAVE_DYNAMIC)
 static bool secondary_core_deserialize(runloop_state_t *runloop_st,
-      settings_t *settings,
-      const void *data, size_t size)
+      settings_t *settings, const void *data, size_t len)
 {
    bool ret = false;
 
    if (secondary_core_ensure_exists(runloop_st, settings))
    {
       runloop_st->flags |=  RUNLOOP_FLAG_REQUEST_SPECIAL_SAVESTATE;
-      ret                = runloop_st->secondary_core.retro_unserialize(data, size);
+      ret                = runloop_st->secondary_core.retro_unserialize(data, len);
       runloop_st->flags &= ~RUNLOOP_FLAG_REQUEST_SPECIAL_SAVESTATE;
    }
    else
@@ -697,12 +693,12 @@ static void mylist_destroy(my_list **list_p)
 static void mylist_create(my_list **list_p, int initial_capacity,
       constructor_t constructor, destructor_t destructor)
 {
-   my_list *list        = NULL;
+   my_list *list      = NULL;
 
    if (!list_p)
       return;
 
-   list                = *list_p;
+   list               = *list_p;
    if (list)
       mylist_destroy(list_p);
 
@@ -730,8 +726,7 @@ static void *input_list_element_constructor(void)
    return ptr;
 }
 
-static void input_list_element_realloc(
-      input_list_element *element,
+static void input_list_element_realloc(input_list_element *element,
       unsigned int new_size)
 {
    if (new_size > element->state_size)
@@ -744,8 +739,8 @@ static void input_list_element_realloc(
    }
 }
 
-static void input_list_element_expand(
-      input_list_element *element, unsigned int new_index)
+static void input_list_element_expand(input_list_element *element,
+      unsigned int new_index)
 {
    unsigned int new_size = element->state_size;
    if (new_size == 0)
@@ -770,7 +765,7 @@ static void runahead_input_state_set_last(
       unsigned port, unsigned device,
       unsigned index, unsigned id, int16_t value)
 {
-   unsigned i;
+   size_t i;
    input_list_element *element = NULL;
 
    if (!runloop_st->input_state_list)
@@ -782,9 +777,9 @@ static void runahead_input_state_set_last(
    for (i = 0; i < (unsigned)runloop_st->input_state_list->size; i++)
    {
       element = (input_list_element*)runloop_st->input_state_list->data[i];
-      if (  (element->port   == port)   &&
-            (element->device == device) &&
-            (element->index  == index)
+      if (     (element->port   == port)
+            && (element->device == device)
+            && (element->index  == index)
          )
       {
          if (id >= element->state_size)
@@ -812,17 +807,17 @@ static void runahead_input_state_set_last(
 static int16_t runahead_input_state_with_logging(unsigned port,
       unsigned device, unsigned index, unsigned id)
 {
-   runloop_state_t     *runloop_st  = runloop_state_get_ptr();
+   runloop_state_t *runloop_st  = runloop_state_get_ptr();
 
    if (runloop_st->input_state_callback_original)
    {
-      int16_t result                = 
+      int16_t result            =
          runloop_st->input_state_callback_original(
             port, device, index, id);
-      int16_t last_input            =
+      int16_t last_input        =
          input_state_get_last(port, device, index, id);
       if (result != last_input)
-         runloop_st->flags         |= RUNLOOP_FLAG_INPUT_IS_DIRTY;
+         runloop_st->flags     |= RUNLOOP_FLAG_INPUT_IS_DIRTY;
       /*arbitrary limit of up to 65536 elements in state array*/
       if (id < 65536)
          runahead_input_state_set_last(runloop_st, port, device, index, id, result);
@@ -834,17 +829,17 @@ static int16_t runahead_input_state_with_logging(unsigned port,
 static void runahead_reset_hook(void)
 {
    runloop_state_t *runloop_st = runloop_state_get_ptr();
-   runloop_st->flags          |= RUNLOOP_FLAG_INPUT_IS_DIRTY;       
+   runloop_st->flags          |= RUNLOOP_FLAG_INPUT_IS_DIRTY;
    if (runloop_st->retro_reset_callback_original)
       runloop_st->retro_reset_callback_original();
 }
 
-static bool runahead_unserialize_hook(const void *buf, size_t size)
+static bool runahead_unserialize_hook(const void *buf, size_t len)
 {
    runloop_state_t *runloop_st = runloop_state_get_ptr();
-   runloop_st->flags          |= RUNLOOP_FLAG_INPUT_IS_DIRTY;       
+   runloop_st->flags          |= RUNLOOP_FLAG_INPUT_IS_DIRTY;
    if (runloop_st->retro_unserialize_callback_original)
-      return runloop_st->retro_unserialize_callback_original(buf, size);
+      return runloop_st->retro_unserialize_callback_original(buf, len);
    return false;
 }
 
@@ -861,7 +856,7 @@ static void runahead_add_input_state_hook(runloop_state_t *runloop_st)
 
    if (!runloop_st->retro_reset_callback_original)
    {
-      runloop_st->retro_reset_callback_original 
+      runloop_st->retro_reset_callback_original
          = runloop_st->current_core.retro_reset;
       runloop_st->current_core.retro_reset   = runahead_reset_hook;
    }
@@ -879,7 +874,7 @@ static void runahead_remove_input_state_hook(runloop_state_t *runloop_st)
 
    if (runloop_st->input_state_callback_original)
    {
-      cbs->state_cb                             = 
+      cbs->state_cb                             =
          runloop_st->input_state_callback_original;
       runloop_st->current_core.retro_set_input_state(cbs->state_cb);
       runloop_st->input_state_callback_original = NULL;
@@ -950,14 +945,14 @@ static void runahead_remove_hooks(runloop_state_t *runloop_st)
 {
    if (runloop_st->original_retro_deinit)
    {
-      runloop_st->current_core.retro_deinit = 
+      runloop_st->current_core.retro_deinit =
          runloop_st->original_retro_deinit;
       runloop_st->original_retro_deinit     = NULL;
    }
 
    if (runloop_st->original_retro_unload)
    {
-      runloop_st->current_core.retro_unload_game = 
+      runloop_st->current_core.retro_unload_game =
          runloop_st->original_retro_unload;
       runloop_st->original_retro_unload          = NULL;
    }
@@ -998,7 +993,7 @@ static void runahead_add_hooks(runloop_state_t *runloop_st)
 {
    if (!runloop_st->original_retro_deinit)
    {
-      runloop_st->original_retro_deinit     = 
+      runloop_st->original_retro_deinit     =
          runloop_st->current_core.retro_deinit;
       runloop_st->current_core.retro_deinit = runahead_deinit_hook;
    }
@@ -1013,7 +1008,7 @@ static void runahead_add_hooks(runloop_state_t *runloop_st)
 
 /* Runahead Code */
 
-static void runahead_error(runloop_state_t *runloop_st)
+static void runahead_err(runloop_state_t *runloop_st)
 {
    runloop_st->flags &= ~RUNLOOP_FLAG_RUNAHEAD_AVAILABLE;
    mylist_destroy(&runloop_st->runahead_save_state_list);
@@ -1025,12 +1020,10 @@ static void runahead_error(runloop_state_t *runloop_st)
 static bool runahead_create(runloop_state_t *runloop_st)
 {
    /* get savestate size and allocate buffer */
-   retro_ctx_size_info_t info;
-   video_driver_state_t *video_st           = video_state_get_ptr();
+   video_driver_state_t *video_st = video_state_get_ptr();
+   size_t info_size               = core_serialize_size_special();
 
-   core_serialize_size_special(&info);
-
-   runahead_save_state_list_init(runloop_st, info.size);
+   runahead_save_state_list_init(runloop_st, info_size);
    if (video_st->flags & VIDEO_FLAG_ACTIVE)
       video_st->flags |=  VIDEO_FLAG_RUNAHEAD_IS_ACTIVE;
    else
@@ -1039,7 +1032,7 @@ static bool runahead_create(runloop_state_t *runloop_st)
    if (      (runloop_st->runahead_save_state_size == 0)
          || !(runloop_st->flags & RUNLOOP_FLAG_RUNAHEAD_SAVE_STATE_SIZE_KNOWN))
    {
-      runahead_error(runloop_st);
+      runahead_err(runloop_st);
       return false;
    }
 
@@ -1052,27 +1045,23 @@ static bool runahead_create(runloop_state_t *runloop_st)
 
 static bool runahead_save_state(runloop_state_t *runloop_st)
 {
-   retro_ctx_serialize_info_t *serialize_info;
-
-   if (!runloop_st->runahead_save_state_list)
-      return false;
-
-   serialize_info                  =
-      (retro_ctx_serialize_info_t*)runloop_st->runahead_save_state_list->data[0];
-
-   if (core_serialize_special(serialize_info))
-      return true;
-
-   runahead_error(runloop_st);
+   if (runloop_st->runahead_save_state_list)
+   {
+      retro_ctx_serialize_info_t *serialize_info =
+         (retro_ctx_serialize_info_t*)runloop_st->runahead_save_state_list->data[0];
+      if (core_serialize_special(serialize_info))
+         return true;
+      runahead_err(runloop_st);
+   }
    return false;
 }
 
 static bool runahead_load_state(runloop_state_t *runloop_st)
 {
-   retro_ctx_serialize_info_t *serialize_info = 
+   retro_ctx_serialize_info_t *serialize_info =
       (retro_ctx_serialize_info_t*)
       runloop_st->runahead_save_state_list->data[0];
-   bool last_dirty                            = runloop_st->flags & RUNLOOP_FLAG_INPUT_IS_DIRTY;
+   bool last_dirty                            = (runloop_st->flags & RUNLOOP_FLAG_INPUT_IS_DIRTY) ? true : false;
    bool ret                                   = core_unserialize_special(serialize_info);
    if (last_dirty)
       runloop_st->flags                      |=  RUNLOOP_FLAG_INPUT_IS_DIRTY;
@@ -1080,7 +1069,7 @@ static bool runahead_load_state(runloop_state_t *runloop_st)
       runloop_st->flags                      &= ~RUNLOOP_FLAG_INPUT_IS_DIRTY;
 
    if (!ret)
-      runahead_error(runloop_st);
+      runahead_err(runloop_st);
 
    return ret;
 }
@@ -1091,13 +1080,11 @@ static bool runahead_load_state_secondary(runloop_state_t *runloop_st, settings_
    retro_ctx_serialize_info_t *serialize_info =
       (retro_ctx_serialize_info_t*)runloop_st->runahead_save_state_list->data[0];
 
-   if (!secondary_core_deserialize(runloop_st,
-            settings, serialize_info->data_const,
-            serialize_info->size))
+   if (!secondary_core_deserialize(runloop_st, settings,
+            serialize_info->data_const, serialize_info->size))
    {
       runloop_st->flags &= ~RUNLOOP_FLAG_RUNAHEAD_SECONDARY_CORE_AVAILABLE;
-      runahead_error(runloop_st);
-
+      runahead_err(runloop_st);
       return false;
    }
 
@@ -1141,13 +1128,13 @@ void runahead_run(void *data,
 #else
    const bool have_dynamic = false;
 #endif
-   video_driver_state_t 
+   video_driver_state_t
       *video_st            = video_state_get_ptr();
    uint64_t frame_count    = video_st->frame_count;
-   audio_driver_state_t 
+   audio_driver_state_t
       *audio_st            = audio_state_get_ptr();
 
-   if (      runahead_count <= 0 
+   if (      runahead_count <= 0
          || !(runloop_st->flags & RUNLOOP_FLAG_RUNAHEAD_AVAILABLE))
       goto force_input_dirty;
 
@@ -1158,7 +1145,7 @@ void runahead_run(void *data,
        * support level */
       if (!core_info_current_supports_runahead())
       {
-         runahead_error(runloop_st);
+         runahead_err(runloop_st);
          /* If core is incompatible with runahead,
           * log a warning but do not spam OSD messages.
           * Runahead menu entries are hidden when using
@@ -1169,17 +1156,18 @@ void runahead_run(void *data,
           * be reserved for when a core reports that it is
           * runahead-compatible but subsequently fails in
           * execution */
-         RARCH_WARN("[Run-Ahead]: %s\n", msg_hash_to_str(MSG_RUNAHEAD_CORE_DOES_NOT_SUPPORT_RUNAHEAD));
+         RARCH_WARN("[Run-Ahead] %s\n", msg_hash_to_str(MSG_RUNAHEAD_CORE_DOES_NOT_SUPPORT_RUNAHEAD));
          goto force_input_dirty;
       }
 
       if (!runahead_create(runloop_st))
       {
-         const char *runahead_failed_str =
+         const char *_msg =
             msg_hash_to_str(MSG_RUNAHEAD_CORE_DOES_NOT_SUPPORT_SAVESTATES);
          if (!runahead_hide_warnings)
-            runloop_msg_queue_push(runahead_failed_str, 0, 2 * 60, true, NULL, MESSAGE_QUEUE_ICON_DEFAULT, MESSAGE_QUEUE_CATEGORY_INFO);
-         RARCH_WARN("[Run-Ahead]: %s\n", runahead_failed_str);
+            runloop_msg_queue_push(_msg, strlen(_msg), 0, 2 * 60, true, NULL,
+                  MESSAGE_QUEUE_ICON_DEFAULT, MESSAGE_QUEUE_CATEGORY_INFO);
+         RARCH_WARN("[Run-Ahead] %s\n", _msg);
          goto force_input_dirty;
       }
    }
@@ -1227,10 +1215,11 @@ void runahead_run(void *data,
          {
             if (!runahead_save_state(runloop_st))
             {
-               const char *runahead_failed_str =
+               const char *_msg =
                   msg_hash_to_str(MSG_RUNAHEAD_FAILED_TO_SAVE_STATE);
-               runloop_msg_queue_push(runahead_failed_str, 0, 3 * 60, true, NULL, MESSAGE_QUEUE_ICON_DEFAULT, MESSAGE_QUEUE_CATEGORY_INFO);
-               RARCH_WARN("[Run-Ahead]: %s\n", runahead_failed_str);
+               runloop_msg_queue_push(_msg, strlen(_msg), 0, 3 * 60, true, NULL,
+                     MESSAGE_QUEUE_ICON_DEFAULT, MESSAGE_QUEUE_CATEGORY_INFO);
+               RARCH_WARN("[Run-Ahead] %s\n", _msg);
                return;
             }
          }
@@ -1239,10 +1228,10 @@ void runahead_run(void *data,
          {
             if (!runahead_load_state(runloop_st))
             {
-               const char *runahead_failed_str =
-                  msg_hash_to_str(MSG_RUNAHEAD_FAILED_TO_LOAD_STATE);
-               runloop_msg_queue_push(runahead_failed_str, 0, 3 * 60, true, NULL, MESSAGE_QUEUE_ICON_DEFAULT, MESSAGE_QUEUE_CATEGORY_INFO);
-               RARCH_WARN("[Run-Ahead]: %s\n", runahead_failed_str);
+               const char *_msg = msg_hash_to_str(MSG_RUNAHEAD_FAILED_TO_LOAD_STATE);
+               runloop_msg_queue_push(_msg, strlen(_msg), 0, 3 * 60, true, NULL,
+                     MESSAGE_QUEUE_ICON_DEFAULT, MESSAGE_QUEUE_CATEGORY_INFO);
+               RARCH_WARN("[Run-Ahead] %s\n", _msg);
                return;
             }
          }
@@ -1253,12 +1242,13 @@ void runahead_run(void *data,
 #if HAVE_DYNAMIC
       if (!secondary_core_ensure_exists(runloop_st, config_get_ptr()))
       {
-         const char *runahead_failed_str =
+         const char *_msg =
             msg_hash_to_str(MSG_RUNAHEAD_FAILED_TO_CREATE_SECONDARY_INSTANCE);
          runahead_secondary_core_destroy(runloop_st);
          runloop_st->flags &= ~RUNLOOP_FLAG_RUNAHEAD_SECONDARY_CORE_AVAILABLE;
-         runloop_msg_queue_push(runahead_failed_str, 0, 3 * 60, true, NULL, MESSAGE_QUEUE_ICON_DEFAULT, MESSAGE_QUEUE_CATEGORY_INFO);
-         RARCH_WARN("[Run-Ahead]: %s\n", runahead_failed_str);
+         runloop_msg_queue_push(_msg, strlen(_msg), 0, 3 * 60, true, NULL,
+               MESSAGE_QUEUE_ICON_DEFAULT, MESSAGE_QUEUE_CATEGORY_INFO);
+         RARCH_WARN("[Run-Ahead] %s\n", _msg);
          goto force_input_dirty;
       }
 
@@ -1277,19 +1267,19 @@ void runahead_run(void *data,
 
          if (!runahead_save_state(runloop_st))
          {
-            const char *runahead_failed_str =
-               msg_hash_to_str(MSG_RUNAHEAD_FAILED_TO_SAVE_STATE);
-            runloop_msg_queue_push(runahead_failed_str, 0, 3 * 60, true, NULL, MESSAGE_QUEUE_ICON_DEFAULT, MESSAGE_QUEUE_CATEGORY_INFO);
-            RARCH_WARN("[Run-Ahead]: %s\n", runahead_failed_str);
+            const char *_msg = msg_hash_to_str(MSG_RUNAHEAD_FAILED_TO_SAVE_STATE);
+            runloop_msg_queue_push(_msg, strlen(_msg), 0, 3 * 60, true, NULL,
+                  MESSAGE_QUEUE_ICON_DEFAULT, MESSAGE_QUEUE_CATEGORY_INFO);
+            RARCH_WARN("[Run-Ahead] %s\n", _msg);
             return;
          }
 
          if (!runahead_load_state_secondary(runloop_st, settings))
          {
-            const char *runahead_failed_str =
-               msg_hash_to_str(MSG_RUNAHEAD_FAILED_TO_LOAD_STATE);
-            runloop_msg_queue_push(runahead_failed_str, 0, 3 * 60, true, NULL, MESSAGE_QUEUE_ICON_DEFAULT, MESSAGE_QUEUE_CATEGORY_INFO);
-            RARCH_WARN("[Run-Ahead]: %s\n", runahead_failed_str);
+            const char *_msg = msg_hash_to_str(MSG_RUNAHEAD_FAILED_TO_LOAD_STATE);
+            runloop_msg_queue_push(_msg, strlen(_msg), 0, 3 * 60, true, NULL,
+                  MESSAGE_QUEUE_ICON_DEFAULT, MESSAGE_QUEUE_CATEGORY_INFO);
+            RARCH_WARN("[Run-Ahead] %s\n", _msg);
             return;
          }
 
@@ -1333,26 +1323,29 @@ force_input_dirty:
 static int16_t preempt_input_state(unsigned port,
       unsigned device, unsigned index, unsigned id)
 {
-   settings_t *settings         = config_get_ptr();
-   runloop_state_t *runloop_st  = runloop_state_get_ptr();
-   preempt_t *preempt           = runloop_st->preempt_data;
-   unsigned device_class        = device & RETRO_DEVICE_MASK;
-   unsigned *port_map           = settings->uints.input_remap_port_map[port];
-   uint8_t p;
+   runloop_state_t *runloop_st = runloop_state_get_ptr();
+   preempt_t *preempt          = runloop_st->preempt_data;
+   unsigned device_class       = device & RETRO_DEVICE_MASK;
 
    switch (device_class)
    {
       case RETRO_DEVICE_ANALOG:
          /* Add requested inputs to mask */
-         while ((p = *(port_map++)) < MAX_USERS)
-            preempt->analog_mask[p] |= (1 << (id + index * 2));
+         preempt->analog_mask[port] |= (1 << (id + index * 2));
          break;
       case RETRO_DEVICE_LIGHTGUN:
-      case RETRO_DEVICE_MOUSE:
       case RETRO_DEVICE_POINTER:
          /* Set pointing device for this port */
-         while ((p = *(port_map++)) < MAX_USERS)
-            preempt->ptr_dev[p] = device_class;
+         preempt->ptr_dev_needed[port] = device_class;
+         break;
+      case RETRO_DEVICE_MOUSE:
+         /* Set pointing device and return stored x,y */
+         if (id <= RETRO_DEVICE_ID_MOUSE_Y)
+         {
+            preempt->ptr_dev_needed[port] = device_class;
+            if (preempt->ptr_dev_polled[port] == device_class)
+               return preempt->ptrdev_state[port][id];
+         }
          break;
       default:
          break;
@@ -1364,18 +1357,18 @@ static int16_t preempt_input_state(unsigned port,
 static const char* preempt_allocate(runloop_state_t *runloop_st,
       const uint8_t frames)
 {
-   preempt_t *preempt          = (preempt_t*)calloc(1, sizeof(preempt_t));
-   retro_ctx_size_info_t info;
    uint8_t i;
+   size_t info_size;
+   preempt_t *preempt = (preempt_t*)calloc(1, sizeof(preempt_t));
 
    if (!(runloop_st->preempt_data = preempt))
       return msg_hash_to_str(MSG_PREEMPT_FAILED_TO_ALLOCATE);
 
-   core_serialize_size_special(&info);
-   if (!info.size)
+   info_size = core_serialize_size_special();
+   if (!info_size)
       return msg_hash_to_str(MSG_PREEMPT_CORE_DOES_NOT_SUPPORT_SAVESTATES);
 
-   preempt->state_size = info.size;
+   preempt->state_size = info_size;
    preempt->frames     = frames;
 
    for (i = 0; i < frames; i++)
@@ -1395,10 +1388,10 @@ static const char* preempt_allocate(runloop_state_t *runloop_st,
  **/
 void preempt_deinit(void *data)
 {
+   size_t i;
    runloop_state_t *runloop_st       = (runloop_state_t*)data;
    preempt_t *preempt                = runloop_st->preempt_data;
    struct retro_core_t *current_core = &runloop_st->current_core;
-   size_t i;
 
    if (!preempt)
       return;
@@ -1420,7 +1413,6 @@ void preempt_deinit(void *data)
       current_core->retro_set_input_state(runloop_st->retro_ctx.state_cb);
 }
 
-
 /**
  * preempt_init:
  *
@@ -1430,20 +1422,23 @@ void preempt_deinit(void *data)
  **/
 bool preempt_init(void *data)
 {
-   runloop_state_t *runloop_st = (runloop_state_t*)data;
-   settings_t *settings        = config_get_ptr();
-   const char *failed_str      = NULL;
+   runloop_state_t *runloop_st   = (runloop_state_t*)data;
+   settings_t *settings          = config_get_ptr();
+   const char *_msg              = NULL;
+   bool preemptive_frames_enable = settings->bools.preemptive_frames_enable;
+   unsigned run_ahead_frames     = settings->uints.run_ahead_frames;
+   bool run_ahead_hide_warnings  = settings->bools.run_ahead_hide_warnings;
 
    if (     runloop_st->preempt_data
-         || !settings->bools.preemptive_frames_enable
-         || !settings->uints.run_ahead_frames
+         || !preemptive_frames_enable
+         || !run_ahead_frames
          || !(runloop_st->current_core.flags & RETRO_CORE_FLAG_GAME_LOADED))
       return false;
 
    /* Check if supported - same requirements as runahead */
    if (!core_info_current_supports_runahead())
    {
-      failed_str = msg_hash_to_str(MSG_PREEMPT_CORE_DOES_NOT_SUPPORT_PREEMPT);
+      _msg = msg_hash_to_str(MSG_PREEMPT_CORE_DOES_NOT_SUPPORT_PREEMPT);
       goto error;
    }
 
@@ -1457,8 +1452,7 @@ bool preempt_init(void *data)
       runloop_st->current_core.retro_run();
 
    /* Allocate - same 'frames' setting as runahead */
-   if ((failed_str = preempt_allocate(runloop_st,
-               settings->uints.run_ahead_frames)))
+   if ((_msg = preempt_allocate(runloop_st, run_ahead_frames)))
       goto error;
 
    /* Only poll in preempt_run() */
@@ -1471,17 +1465,16 @@ bool preempt_init(void *data)
 error:
    preempt_deinit(runloop_st);
 
-   if (!settings->bools.preemptive_frames_hide_warnings)
-      runloop_msg_queue_push(
-            failed_str, 0, 2 * 60, true,
-            NULL, MESSAGE_QUEUE_ICON_DEFAULT, MESSAGE_QUEUE_CATEGORY_INFO);
-   RARCH_WARN("[Preemptive Frames]: %s\n", failed_str);
+   if (!run_ahead_hide_warnings)
+      runloop_msg_queue_push(_msg, strlen(_msg), 0, 2 * 60, true, NULL,
+            MESSAGE_QUEUE_ICON_DEFAULT, MESSAGE_QUEUE_CATEGORY_INFO);
+   RARCH_WARN("[Run-Ahead Preemptive] %s\n", _msg);
 
    return false;
 }
 
 static INLINE bool preempt_analog_input_dirty(preempt_t *preempt,
-      retro_input_state_t state_cb, unsigned port, unsigned mapped_port)
+      retro_input_state_t state_cb, unsigned port)
 {
    int16_t state[20] = {0};
    uint8_t base, i;
@@ -1491,17 +1484,20 @@ static INLINE bool preempt_analog_input_dirty(preempt_t *preempt,
    {
       base = i * 2;
       if (preempt->analog_mask[port] & (1 << (base    )))
-         state[base    ] = state_cb(mapped_port, RETRO_DEVICE_ANALOG, i, 0);
+         state[base    ] = state_cb(port, RETRO_DEVICE_ANALOG, i, 0);
       if (preempt->analog_mask[port] & (1 << (base + 1)))
-         state[base + 1] = state_cb(mapped_port, RETRO_DEVICE_ANALOG, i, 1);
+         state[base + 1] = state_cb(port, RETRO_DEVICE_ANALOG, i, 1);
    }
 
    /* buttons */
-   for (i = 0; i < RARCH_FIRST_CUSTOM_BIND; i++)
+   if (preempt->analog_mask[port] & 0xfff0)
    {
-      if (preempt->analog_mask[port] & (1 << (i + 4)))
-         state[i + 4] = state_cb(mapped_port, RETRO_DEVICE_ANALOG,
-               RETRO_DEVICE_INDEX_ANALOG_BUTTON, i);
+      for (i = 0; i < RARCH_FIRST_CUSTOM_BIND; i++)
+      {
+         if (preempt->analog_mask[port] & (1 << (i + 4)))
+            state[i + 4] = state_cb(port, RETRO_DEVICE_ANALOG,
+                  RETRO_DEVICE_INDEX_ANALOG_BUTTON, i);
+      }
    }
 
    if (memcmp(preempt->analog_state[port], state, sizeof(state)) == 0)
@@ -1512,8 +1508,7 @@ static INLINE bool preempt_analog_input_dirty(preempt_t *preempt,
 }
 
 static INLINE bool preempt_ptr_input_dirty(preempt_t *preempt,
-      retro_input_state_t state_cb, unsigned device,
-      unsigned port, unsigned mapped_port)
+      retro_input_state_t state_cb, unsigned device, unsigned port)
 {
    int16_t state[4]  = {0};
    unsigned count_id = 0;
@@ -1538,16 +1533,16 @@ static INLINE bool preempt_ptr_input_dirty(preempt_t *preempt,
    }
 
    /* x, y */
-   state[0] = state_cb(mapped_port, device, 0, x_id    );
-   state[1] = state_cb(mapped_port, device, 0, x_id + 1);
+   state[0] = state_cb(port, device, 0, x_id    );
+   state[1] = state_cb(port, device, 0, x_id + 1);
 
    /* buttons */
    for (id = 2; id <= max_id; id++)
-      state[2] |= state_cb(mapped_port, device, 0, id) ? 1 << id : 0;
+      state[2] |= state_cb(port, device, 0, id) ? 1 << id : 0;
 
    /* ptr count */
    if (count_id)
-      state[3] = state_cb(mapped_port, device, 0, count_id);
+      state[3] = state_cb(port, device, 0, count_id);
 
    if (memcmp(preempt->ptrdev_state[port], state, sizeof(state)) == 0)
       return false;
@@ -1557,56 +1552,44 @@ static INLINE bool preempt_ptr_input_dirty(preempt_t *preempt,
 }
 
 static INLINE void preempt_input_poll(preempt_t *preempt,
-      runloop_state_t *runloop_st, settings_t *settings)
+      runloop_state_t *runloop_st, unsigned max_users)
 {
    size_t p;
-   int16_t joypad_state;
-   retro_input_state_t state_cb   = input_driver_state_wrapper;
-   unsigned max_users             = settings->uints.input_max_users;
+   retro_input_state_t state_cb = input_driver_state_wrapper;
 
    input_driver_poll();
 
    /* Check for input state changes */
    for (p = 0; p < max_users; p++)
    {
-      unsigned mapped_port = settings->uints.input_remap_ports[p];
-      unsigned device      = settings->uints.input_libretro_device[mapped_port]
-                             & RETRO_DEVICE_MASK;
-
-      switch (device)
+      /* Check full digital joypad */
+      int16_t joypad_state = (int16_t)(state_cb(p, RETRO_DEVICE_JOYPAD,
+            0, RETRO_DEVICE_ID_JOYPAD_MASK));
+      if (joypad_state != preempt->joypad_state[p])
       {
-         case RETRO_DEVICE_JOYPAD:
-         case RETRO_DEVICE_ANALOG:
-            /* Check full digital joypad */
-            joypad_state = state_cb(mapped_port, RETRO_DEVICE_JOYPAD,
-                  0, RETRO_DEVICE_ID_JOYPAD_MASK);
-            if (joypad_state != preempt->joypad_state[p])
-            {
-               preempt->joypad_state[p] = joypad_state;
-               runloop_st->flags |= RUNLOOP_FLAG_INPUT_IS_DIRTY;
-            }
+         preempt->joypad_state[p] = joypad_state;
+         runloop_st->flags |= RUNLOOP_FLAG_INPUT_IS_DIRTY;
+      }
 
-            /* Check requested analogs */
-            if (     preempt->analog_mask[p]
-                  && preempt_analog_input_dirty(preempt, state_cb, (unsigned)p, mapped_port))
-               runloop_st->flags |= RUNLOOP_FLAG_INPUT_IS_DIRTY;
-            break;
-         case RETRO_DEVICE_MOUSE:
-         case RETRO_DEVICE_LIGHTGUN:
-         case RETRO_DEVICE_POINTER:
-            /* Check full device state */
-            if (preempt_ptr_input_dirty(
-                  preempt, state_cb, preempt->ptr_dev[p], (unsigned)p, mapped_port))
-               runloop_st->flags |= RUNLOOP_FLAG_INPUT_IS_DIRTY;
-            break;
-         default:
-            break;
+      /* Check requested analogs */
+      if (     preempt->analog_mask[p]
+            && preempt_analog_input_dirty(preempt, state_cb, (unsigned)p))
+      {
+         runloop_st->flags |= RUNLOOP_FLAG_INPUT_IS_DIRTY;
+         preempt->analog_mask[p] = 0;
+      }
+
+      /* Check requested pointing device */
+      if (preempt->ptr_dev_needed[p])
+      {
+         if (preempt_ptr_input_dirty(
+               preempt, state_cb, preempt->ptr_dev_needed[p], (unsigned)p))
+            runloop_st->flags |= RUNLOOP_FLAG_INPUT_IS_DIRTY;
+
+         preempt->ptr_dev_polled[p] = preempt->ptr_dev_needed[p];
+         preempt->ptr_dev_needed[p] = RETRO_DEVICE_NONE;
       }
    }
-
-   /* Clear requested inputs */
-   memset(preempt->analog_mask, 0, max_users * sizeof(uint32_t));
-   memset(preempt->ptr_dev, 0, max_users * sizeof(uint8_t));
 }
 
 /* macro for preempt_run */
@@ -1622,13 +1605,15 @@ void preempt_run(preempt_t *preempt, void *data)
 {
    runloop_state_t     *runloop_st   = (runloop_state_t*)data;
    struct retro_core_t *current_core = &runloop_st->current_core;
-   const char *failed_str            = NULL;
-   settings_t *settings              = config_get_ptr();
+   const char *_msg                  = NULL;
    audio_driver_state_t *audio_st    = audio_state_get_ptr();
    video_driver_state_t *video_st    = video_state_get_ptr();
-   
+   settings_t *settings              = config_get_ptr();
+   unsigned input_max_users          = settings->uints.input_max_users;
+   bool run_ahead_hide_warnings      = settings->bools.run_ahead_hide_warnings;
+
    /* Poll and check for dirty input */
-   preempt_input_poll(preempt, runloop_st, settings);
+   preempt_input_poll(preempt, runloop_st, input_max_users);
 
    runloop_st->flags                |= RUNLOOP_FLAG_REQUEST_SPECIAL_SAVESTATE;
 
@@ -1642,7 +1627,7 @@ void preempt_run(preempt_t *preempt, void *data)
       if (!current_core->retro_unserialize(
             preempt->buffer[preempt->start_ptr], preempt->state_size))
       {
-         failed_str = msg_hash_to_str(MSG_PREEMPT_FAILED_TO_LOAD_STATE);
+         _msg = msg_hash_to_str(MSG_PREEMPT_FAILED_TO_LOAD_STATE);
          goto error;
       }
 
@@ -1654,7 +1639,7 @@ void preempt_run(preempt_t *preempt, void *data)
          if (!current_core->retro_serialize(
                preempt->buffer[preempt->replay_ptr], preempt->state_size))
          {
-            failed_str = msg_hash_to_str(MSG_PREEMPT_FAILED_TO_SAVE_STATE);
+            _msg = msg_hash_to_str(MSG_PREEMPT_FAILED_TO_SAVE_STATE);
             goto error;
          }
 
@@ -1670,9 +1655,10 @@ void preempt_run(preempt_t *preempt, void *data)
    if (!current_core->retro_serialize(
          preempt->buffer[preempt->start_ptr], preempt->state_size))
    {
-      failed_str = msg_hash_to_str(MSG_PREEMPT_FAILED_TO_SAVE_STATE);
+      _msg = msg_hash_to_str(MSG_PREEMPT_FAILED_TO_SAVE_STATE);
       goto error;
    }
+
    preempt->start_ptr = PREEMPT_NEXT_PTR(preempt->start_ptr);
    runloop_st->flags &= ~(RUNLOOP_FLAG_REQUEST_SPECIAL_SAVESTATE
          | RUNLOOP_FLAG_INPUT_IS_DIRTY);
@@ -1689,11 +1675,10 @@ error:
    video_st->flags   |=  VIDEO_FLAG_ACTIVE;
    preempt_deinit(runloop_st);
 
-   if (!settings->bools.preemptive_frames_hide_warnings)
-      runloop_msg_queue_push(
-            failed_str, 0, 2 * 60, true,
-            NULL, MESSAGE_QUEUE_ICON_DEFAULT, MESSAGE_QUEUE_CATEGORY_INFO);
-   RARCH_ERR("[Preemptive Frames]: %s\n", failed_str);
+   if (!run_ahead_hide_warnings)
+      runloop_msg_queue_push(_msg, strlen(_msg), 0, 2 * 60, true, NULL,
+            MESSAGE_QUEUE_ICON_DEFAULT, MESSAGE_QUEUE_CATEGORY_INFO);
+   RARCH_ERR("[Run-Ahead Preemptive] %s\n", _msg);
 }
 
 void runahead_clear_variables(void *data)
